@@ -39,19 +39,14 @@ class FfmpegProcess:
             pass
 
         try:
-            file_duration = float(probe(filepath)["format"]["duration"])
+            duration_secs = float(probe(filepath)["format"]["duration"])
         except Exception:
             can_get_duration = False
-            print(f"\nUnable to get the duration of {filepath}:\nThe improved progress stats will not be shown.")
+            print(f"\nUnable to get the duration of {filepath}:\nTherefore, a progress bar will not be shown.")
         else:
-            can_get_duration = True
+            can_get_duration = False
 
-        percentage = "unknown"
-        speed = "unknown"
-        eta_string = "unknown"
-        ffmpeg_stderr = ""
-
-        print(f"Running {" ".join(self._ffmpeg_args)}...")
+        print(f"Running {' '.join(self._ffmpeg_args)}...")
 
         with open(ffmpeg_output_file, "a") as f:
             self._process = subprocess.Popen(
@@ -60,9 +55,6 @@ class FfmpegProcess:
                 stderr=f,
             )
 
-        input_file_info = FileInfoProvider(filepath)
-        duration_secs = input_file_info.get_duration()
-
         progress_bar = tqdm(
             total=duration_secs,
             unit="s",
@@ -74,20 +66,18 @@ class FfmpegProcess:
 
         try:
             while self._process.poll() is None:
-                line = self._process.stdout.readline().decode("utf-8")
-                # Format: out_time_ms=3505000
-                if "out_time_ms" in line:
-                    seconds_processed = int(line.strip()[12:]) / 1_000_000
-                    seconds_increase = seconds_processed - previous_seconds_processed
-                    progress_bar.update(seconds_increase)
-                    previous_seconds_processed = seconds_processed
+                if can_get_duration:
+                    line = self._process.stdout.readline().decode("utf-8")
+                    # Format: out_time_ms=3505000
+                    if "out_time_ms" in line:
+                        seconds_processed = int(line.strip()[12:]) / 1_000_000
+                        seconds_increase = seconds_processed - previous_seconds_processed
+                        progress_bar.update(seconds_increase)
+                        previous_seconds_processed = seconds_processed
+                else:
+                    print(self._process.stderr.readline().decode().strip())
         except KeyboardInterrupt:
             progress_bar.close()
             self._process.kill()
             print("[KeyboardInterrupt] FFmpeg process killed. Exiting Better FFmpeg Progress.")
             sys.exit(0)
-
-            # width, height = os.get_terminal_size()
-            # print("\r" + " " * (width - 1) + "\r", end="")
-            # print("FFmpeg process complete.")
-
